@@ -8,8 +8,9 @@ __author__ = 'https://github.com/akvilary'
 import uuid
 import json
 
-from sqlconstructor.abstracts.string_convertible import StringConvertible
-from sqlconstructor.abstracts.special_json_convertible import SpecialJsonConvertible
+from sqlconstructor.constants import DIALECT
+from sqlconstructor.utils.classes.string_convertible import StringConvertible
+from sqlconstructor.utils.classes.json_convertion_requier import JsonConvertionRequier
 
 
 class SqlEncoder(json.JSONEncoder):
@@ -20,14 +21,11 @@ class SqlEncoder(json.JSONEncoder):
     """
 
     def default(self, o):
-        if isinstance(o, SpecialJsonConvertible):
-            return o.__json_array__()
+        if isinstance(o, JsonConvertionRequier):
+            return o.__as_json__()
         if isinstance(
             o,
-            (
-                uuid.UUID,
-                StringConvertible
-            ),
+            (uuid.UUID, StringConvertible),
         ):
             return str(o)
         if isinstance(o, set):
@@ -35,6 +33,6 @@ class SqlEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, o)
 
 
-def convert_dict_to_sql_json(dictionary: dict) -> str:
+def convert_dict_to_sql_json(dictionary: dict | list | str) -> str:
     """Convert python dictionary to sql representation"""
-    return json.dumps(dictionary, cls=SqlEncoder)
+    return f"""{'E' if DIALECT == 'PostgreSQL' else ''}'{json.dumps(dictionary, cls=SqlEncoder)}'"""
