@@ -4,9 +4,9 @@ from sqlconstructor import SqlCol
 
 @pytest.mark.SqlCol
 def test_add():
-    assert (SqlCol('a') + ' "b"') == '"a" "b"'
+    assert str(SqlCol('a') + ' "b"') == '"a" "b"'
 
 
 @pytest.mark.SqlVal
 def test_radd():
-    assert ('"a" ' + SqlCol('b')) == '"a" "b"'
+    assert str('"a" ' + SqlCol('b')) == '"a" "b"'
